@@ -1073,7 +1073,7 @@ BOOL cmd_completion(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         sObject* block = SCOMPLETION(compl).mBlock;
                         if(!fd_write(nextout, SBLOCK(block).mSource, strlen(SBLOCK(block).mSource))) 
                         {
-                            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                             return FALSE;
                         }
@@ -1112,12 +1112,12 @@ BOOL cmd_readline_line_buffer(sObject* nextin, sObject* nextout, sRunInfo* runin
 {
     if(!runinfo->mFilter) {
         if(!fd_write(nextout, rl_line_buffer, strlen(rl_line_buffer))) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
         if(!fd_write(nextout, "\n", 1)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -1135,7 +1135,7 @@ BOOL cmd_readline_point(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int n = snprintf(buf, BUFSIZ, "%d\n", rl_point);
         if(!fd_write(nextout, buf, n)) {
             sCommand* command = runinfo->mCommand;
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -1252,13 +1252,13 @@ BOOL cmd_readline_history(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         char* line = (*entries)->line;
         if(!fd_write(nextout, line, strlen(line)))
         {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
         if(!fd_write(nextout, "\n", 1))
         {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
